@@ -239,15 +239,6 @@ class PyPIRepository(BaseRepository):
 
         return self._dependencies_cache[ireq]
 
-    def copy_ireq_dependencies(
-        self, source: InstallRequirement, dest: InstallRequirement
-    ) -> None:
-        try:
-            self._dependencies_cache[dest] = self._dependencies_cache[source]
-        except KeyError:
-            # `source` may not be in cache yet.
-            pass
-
     def _get_project(self, ireq: InstallRequirement) -> Any:
         """
         Return a dict of a project info from PyPI JSON API for a given
